@@ -1708,7 +1708,7 @@ void parse_step(osrm_route_legs_t &route, json::Array &steps)
         current_step.name = get_string("name", curret_json_step);
         current_step.ref = get_string("ref", curret_json_step);
         current_step.pronunciation = get_string("pronunciation", curret_json_step);
-        //destinations?
+        current_step.destinations = get_string("destinations", curret_json_step);
         current_step.exits = get_string("exits", curret_json_step);
         current_step.mode = get_string("mode", curret_json_step);
         if(curret_json_step.values.find("maneuver") != curret_json_step.values.end())
@@ -1807,6 +1807,10 @@ void parse_maneuver(osrm_step_t &step, json::Object &maneuver)
     }
     step.maneuver->type = get_string("type", maneuver);
     step.maneuver->modifier = get_string("modifier", maneuver);
+    if(maneuver.values.find("exit") != maneuver.values.end())
+    {
+        step.maneuver->exit = maneuver.values["exit"].get<json::Number>().value;
+    }
 }
 
 void destroy_maneuver(osrm_maneuver_t *maneuver)
